define([
  "dojo/_base/declare",
  "dojo/ready",
  "dojo/on",
  "esri/main",
  "esri/arcgis/utils",
  "esri/arcgis/Portal",
  "esri/dijit/Legend"
], function (declare, ready, on, esri1, esri2, esriPortal) {

// BEGIN maps and apps custom scroll.
  return declare('arcGISWebmapField', [], {

    _mapElementId: null,
    _geocodeUrl: null,
    _location: null,
    _map: null,
    _mapId: null,
    _mapAppId: null,

    constructor: function (baseUrl, elBaseSuffix) {
      this.setGeocodeUrl(baseUrl);
      this.setLocation(elBaseSuffix);
      this.setMapElementId('arcgis-webmap-field-' + elBaseSuffix);
    },

    setLocation: function (suffix) {
      this._location = suffix;
    },

    setMapElementId: function (id) {
      this._mapElementId = id;
    },

    setGeocodeUrl: function (baseUrl) {
      this._geocodeUrl = baseUrl;
    },

    setMapId: function (mapId) {
      this._mapId = mapId;
    },

    setMapAppId: function (mapAppId) {
      this._mapAppId = mapAppId;
    },

    buildLayersList: function (layers) {

      // Layers  arg is response.itemInfo.itemData.operationalLayers.
      var layerInfos = [];
      dojo.forEach(layers, function (mapLayer, index) {
        var layerInfo = {};
        if (mapLayer.featureCollection && mapLayer.type !== "CSV") {
          if (mapLayer.featureCollection.showLegend === true) {
            dojo.forEach(mapLayer.featureCollection.layers, function (fcMapLayer) {
              if (fcMapLayer.showLegend !== false) {
                layerInfo = {
                  "layer": fcMapLayer.layerObject,
                  "title": mapLayer.title,
                  "defaultSymbol": false
                };
                if (mapLayer.featureCollection.layers.length > 1) {
                  layerInfo.title += " - " + fcMapLayer.layerDefinition.name;
                }
                layerInfos.push(layerInfo);
              }
            });
          }
        } else if (mapLayer.showLegend !== false && mapLayer.layerObject) {
          var showDefaultSymbol = false;
          if (mapLayer.layerObject.version < 10.1 && (mapLayer.layerObject instanceof esri.layers.ArcGISDynamicMapServiceLayer || mapLayer.layerObject instanceof esri.layers.ArcGISTiledMapServiceLayer)) {
            showDefaultSymbol = true;
          }
          layerInfo = {
            "layer": mapLayer.layerObject,
            "title": mapLayer.title,
            "defaultSymbol": showDefaultSymbol
          };
          // Does it have layers too? If so check to see if showLegend is false.
          if (mapLayer.layers) {
            var hideLayers = dojo.map(dojo.filter(mapLayer.layers, function (lyr) {
              return (lyr.showLegend === false);
            }), function (lyr) {
              return lyr.id;
            });
            if (hideLayers.length) {
              layerInfo.hideLayers = hideLayers;
            }
          }
          layerInfos.push(layerInfo);
        }
      });
      return layerInfos;
    },

    showWebMap: function () {
      if (typeof(this._mapAppId) != 'undefined' && this._mapAppId !== null) {
        var webmap_field = this;
        var requestHandle = esri.request({
          url: esri.arcgis.utils.arcgisUrl + "/" + this._mapAppId + "/data",
          content: {
            f: "json"
          },
          callbackParamName: "callback",
          load: function (response) {
            if (response.values.webmap !== undefined) {
              webmap_field._mapId = response.values.webmap;
              webmap_field.renderMap();
            }
          },
          error: function (response) {
            var e = response.message;
            alert("Unable to create map : " + e);
          }

        });
      }
      else {
        this.renderMap();
      }

    },

    renderMap : function () {
      if (this._map !== null) {
        this._map.destroy();
      }

      esri.arcgis.utils.arcgisUrl = this._geocodeUrl + '/sharing/content/items';
      esri.config.defaults.io.proxyUrl = "/arcgisserver/apis/javascript/proxy/proxy.ashx";

      var mapDeferred = esri.arcgis.utils.createMap(this._mapId, this._mapElementId, {
        mapOptions: {
          sliderStyle: "large"
        }
      });
      mapDeferred.then(
        dojo.hitch(this, function (response) {
          this._map = response.map;
          dojo.byId("arcgis-webmap-titlebar-" + this._location).innerHTML = '<span>' + response.itemInfo.item.title + '</span>';
          map = response.map;

          // Add the legend.
          var layers = response.itemInfo.itemData.operationalLayers;
          var layerInfo = this.buildLayersList(layers);
          var legendDijit = new esri.dijit.Legend({
            map: map,
            layerInfos: layerInfo
          }, "arcgis-webmap-legend-" + this._location);
          legendDijit.startup();
        }),
        function (error) {
          console.log("Map creation failed: ", dojo.toJson(error));
        }
      );
    }

// End of class declare return.
  });

// End of module declaration.
});
